@@ -11,7 +11,7 @@ our $AUTHORITY = 'cpan:JDDPAUSE'; # AUTHORITY
 
 use Carp qw/croak/;
 
-our $VERSION = '1.0.53'; # VERSION
+our $VERSION = '2.0.1'; # VERSION
 
 
 # This section should be replaced on-the-fly at build time
@@ -31,7 +31,7 @@ MarpaX::ESLIF::Value::Type - ESLIF Value Types
 
 =head1 VERSION
 
-version 1.0.53
+version 2.0.1
 
 =head1 SYNOPSIS
 
@@ -44,9 +44,7 @@ version 1.0.53
   $valueType = MarpaX::ESLIF::Value::Type->MARPAESLIF_VALUE_TYPE_FLOAT;         #  5
   $valueType = MarpaX::ESLIF::Value::Type->MARPAESLIF_VALUE_TYPE_DOUBLE;        #  6
   $valueType = MarpaX::ESLIF::Value::Type->MARPAESLIF_VALUE_TYPE_PTR;           #  7
-  $valueType = MarpaX::ESLIF::Value::Type->MARPAESLIF_VALUE_TYPE_PTR_SHALLOW;   #  8
-  $valueType = MarpaX::ESLIF::Value::Type->MARPAESLIF_VALUE_TYPE_ARRAY;         #  9
-  $valueType = MarpaX::ESLIF::Value::Type->MARPAESLIF_VALUE_TYPE_ARRAY_SHALLOW; # 10
+  $valueType = MarpaX::ESLIF::Value::Type->MARPAESLIF_VALUE_TYPE_ARRAY;         #  8
 
 =head1 DESCRIPTION
 
@@ -86,18 +84,10 @@ I<C>'s C<double>.
 
 I<C>'s C<void *>.
 
-=head2 MARPAESLIF_VALUE_TYPE_PTR_SHALLOW
-
-I<C>'s C<void *> where the later is a shallow copy.
-
 =head2 MARPAESLIF_VALUE_TYPE_ARRAY
 
 I<C>'s pointer to a C<{void *, size_t}> structure.
 
-=head2 MARPAESLIF_VALUE_TYPE_ARRAY_SHALLOW
-
-I<C>'s pointer to a C<{void *, size_t}> structure where C<void *> is a shallow copy.
-
 =head1 AUTHOR
 
 Jean-Damien Durand <jeandamiendurand@free.fr>
