@@ -116,11 +116,19 @@
 #define G1_RULE_ACTION_NAME_6                    "G1_rule_action_name_6"
 #define G1_RULE_ACTION_NAME_7                    "G1_rule_action_name_7"
 #define G1_RULE_ACTION_FREE_NAME                 "G1_rule_action_free_name"
+#define G1_RULE_SYMBOLACTION_NAME_1              "G1_rule_symbolaction_name_1"
+#define G1_RULE_SYMBOLACTION_NAME_2              "G1_rule_symbolaction_name_2"
+#define G1_RULE_SYMBOLACTION_NAME_3              "G1_rule_symbolaction_name_3"
+#define G1_RULE_SYMBOLACTION_NAME_4              "G1_rule_symbolaction_name_4"
+#define G1_RULE_SYMBOLACTION_NAME_5              "G1_rule_symbolaction_name_5"
+#define G1_RULE_SYMBOLACTION_NAME_6              "G1_rule_symbolaction_name_6"
 #define G1_RULE_QUANTIFIER_1                     "G1_rule_quantifier_1"
 #define G1_RULE_QUANTIFIER_2                     "G1_rule_quantifier_2"
 #define G1_RULE_SIGNED_INTEGER                   "G1_rule_signed_integer"
+#define G1_RULE_UNSIGNED_INTEGER                 "G1_rule_unsigned_integer"
 #define G1_RULE_GRAMMAR_REFERENCE_1              "G1_rule_grammar_reference_1"
 #define G1_RULE_GRAMMAR_REFERENCE_2              "G1_rule_grammar_reference_2"
+#define G1_RULE_GRAMMAR_REFERENCE_3              "G1_rule_grammar_reference_3"
 #define G1_RULE_DISCARD_1                        "G1_rule_discard_1"
 #define G1_RULE_DISCARD_2                        "G1_rule_discard_2"
 #define G1_RULE_DISCARD_3                        "G1_rule_discard_3"
@@ -229,22 +237,30 @@
 #define G1_ACTION_SINGLE_SYMBOL_2                  "G1_action_single_symbol_2"                  /* done */
 #define G1_ACTION_SINGLE_SYMBOL_3                  "G1_action_single_symbol_3"                  /* done */
 #define G1_ACTION_SINGLE_SYMBOL_4                  "G1_action_single_symbol_4"                  /* done */
-#define G1_ACTION_SYMBOL                           "::shift"
+#define G1_ACTION_SYMBOL                           "::shift" /* symbol ::= <symbol name> */
 #define G1_ACTION_SYMBOL_NAME_1                    "::ascii" /* <symbol name> ::= <bare name> */
 #define G1_ACTION_SYMBOL_NAME_2                    "G1_action_symbol_name_2" /* <symbol name> ::= <bracketed name> */ /* done */
 #define G1_ACTION_ACTION_NAME_1                    "::ascii" /* <action name> ::= <ascii graph name> */
 #define G1_ACTION_ACTION_NAME_2                    "::ascii" /* <action name> ::= '::shift' */
 #define G1_ACTION_ACTION_NAME_3                    "::ascii" /* <action name> ::= '::undef' */
 #define G1_ACTION_ACTION_NAME_4                    "::ascii" /* <action name> ::= '::ascii' */
-#define G1_ACTION_ACTION_NAME_5                    "::ascii" /* <action name> ::= '::translit' */
+#define G1_ACTION_ACTION_NAME_5                    "::ascii" /* <action name> ::= '::convert\\[[^\\]]+\\]/\n" */
 #define G1_ACTION_ACTION_NAME_6                    "::ascii" /* <action name> ::= '::concat' */
 #define G1_ACTION_ACTION_NAME_7                    "::ascii" /* <action name> ::= /::copy\\[\\d+\\]/ */
 #define G1_ACTION_FREE_NAME                        "::ascii" /* <free name> ::= <ascii graph name> */
+#define G1_ACTION_SYMBOLACTION_NAME_1              "::ascii" /* <symbol action name> ::= <ascii graph name> */
+#define G1_ACTION_SYMBOLACTION_NAME_2              "::ascii" /* <symbol action name> ::= '::transfer' */
+#define G1_ACTION_SYMBOLACTION_NAME_3              "::ascii" /* <symbol action name> ::= '::undef' */
+#define G1_ACTION_SYMBOLACTION_NAME_4              "::ascii" /* <symbol action name> ::= '::ascii' */
+#define G1_ACTION_SYMBOLACTION_NAME_5              "::ascii" /* <symbol action name> ::= '::convert\\[[^\\]]+\\]/\n" */
+#define G1_ACTION_SYMBOLACTION_NAME_6              "::ascii" /* <symbol action name> ::= '::concat' */
 #define G1_ACTION_QUANTIFIER_1                     "G1_action_quantifier_1"                     /* done */
 #define G1_ACTION_QUANTIFIER_2                     "G1_action_quantifier_2"                     /* done */
 #define G1_ACTION_SIGNED_INTEGER                   "::ascii" /* <signed integer> ::= /[+-]?\d+/ */
+#define G1_ACTION_UNSIGNED_INTEGER                 "::ascii" /* <unsigned integer> ::= /\d+/ */
 #define G1_ACTION_GRAMMAR_REFERENCE_1              "G1_action_grammar_reference_1"              /* done */
 #define G1_ACTION_GRAMMAR_REFERENCE_2              "G1_action_grammar_reference_2"              /* done */
+#define G1_ACTION_GRAMMAR_REFERENCE_3              "G1_action_grammar_reference_3"              /* done */
 
 typedef struct bootstrap_grammar_terminal {
   int                        idi;                 /* Identifier */
