@@ -1,7 +1,16 @@
 #ifndef MARPAESLIF_INTERNAL_STRUCTURES_H
 #define MARPAESLIF_INTERNAL_STRUCTURES_H
 
+#include <marpaESLIF.h>
+/*
+ * Prior to genericStack inclusion, we want to define a custom type for performance
+ */
+
+#define GENERICSTACK_CUSTOM marpaESLIFValueResult_t
+
+#include <marpaWrapper.h>
 #include <genericStack.h>
+#include <genericLogger.h>
 #include <pcre2.h>
 #include <tconv.h>
 
@@ -93,12 +102,12 @@ struct marpaESLIF_terminal {
 };
 
 struct marpaESLIF_meta {
-  int                          idi;                                    /* Non-terminal Id */
+  int                          idi;                             /* Non-terminal Id */
   char                        *asciinames;
-  marpaESLIF_string_t         *descp;                                  /* Non-terminal description */
-  marpaWrapperGrammar_t       *marpaWrapperGrammarLexemeCloneNoEventp; /* Cloned grammar in lexeme search mode (no event) */
-  int                          lexemeIdi;                              /* Lexeme Id in this cloned grammar */
-  short                       *prioritizedb;                           /* Internal flag to prevent a prioritized symbol to appear more than once as an LHS */
+  marpaESLIF_string_t         *descp;                           /* Non-terminal description */
+  marpaWrapperGrammar_t       *marpaWrapperGrammarLexemeClonep; /* Cloned grammar in lexeme search mode (no event) */
+  int                          lexemeIdi;                       /* Lexeme Id in this cloned grammar */
+  short                       *prioritizedb;                    /* Internal flag to prevent a prioritized symbol to appear more than once as an LHS */
 };
 
 /* Matcher return values */
@@ -154,29 +163,30 @@ struct marpaESLIFSymbol {
   char                        *nullableActions;        /* Nullable semantic */
   int                          propertyBitSet;
   genericStack_t              *lhsRuleStackp;          /* Stack of rules having this symbol as LHS */
+  short                        haveExceptionb;         /* If true, this is the symbol before the '-' character of an exception */
+  marpaESLIF_symbol_t         *exceptionp;             /* Pointer to the exception itself, the one after the '-' character */
 };
 
 /* A rule */
 struct marpaESLIF_rule {
-  int                    idi;                                  /* Rule Id */
-  marpaESLIF_string_t   *descp;                                /* Rule alternative name */
-  short                  descautob;                            /* True if alternative name was autogenerated */
-  char                  *asciishows;                           /* Rule show (ASCII) */
-  marpaESLIF_symbol_t   *lhsp;                                 /* LHS symbol */
-  marpaESLIF_symbol_t   *separatorp;                           /* Eventual separator symbol */
-  genericStack_t        *rhsStackp;                            /* Stack of RHS symbols */
-  marpaESLIF_symbol_t   *exceptionp;                           /* Exception symbol */
-  int                    exceptionIdi;                         /* Exception symbol Id */
-  marpaWrapperGrammar_t *marpaWrapperGrammarExceptionNoEventp; /* Grammar implementation at exception - note that this NEVER have any event */
-  char                  *actions;                              /* Action */
-  char                  *discardEvents;                        /* Discard event name - shallowed with its RHS */
-  short                  discardEventb;                        /* Discard event initial state: 0: off, 1: on - copied to its RHS */
+  int                    idi;                          /* Rule Id */
+  marpaESLIF_string_t   *descp;                        /* Rule alternative name */
+  short                  descautob;                    /* True if alternative name was autogenerated */
+  char                  *asciishows;                   /* Rule show (ASCII) */
+  marpaESLIF_symbol_t   *lhsp;                         /* LHS symbol */
+  marpaESLIF_symbol_t   *separatorp;                   /* Eventual separator symbol */
+  genericStack_t        *rhsStackp;                    /* Stack of RHS symbols */
+  marpaESLIF_symbol_t   *exceptionp;                   /* Exception symbol */
+  int                    exceptionIdi;                 /* Exception symbol Id */
+  char                  *actions;                      /* Action */
+  char                  *discardEvents;                /* Discard event name - shallowed with its RHS */
+  short                  discardEventb;                /* Discard event initial state: 0: off, 1: on - copied to its RHS */
   int                    ranki;
   short                  nullRanksHighb;
   short                  sequenceb;
   short                  properb;
   int                    minimumi;
-  short                  passthroughb;                         /* This rule is a passthrough */
+  short                  passthroughb;                 /* This rule is a passthrough */
   int                    propertyBitSet;
 };
 
@@ -202,7 +212,6 @@ struct marpaESLIF_grammar {
   char                  *starts;                             /* Default start symbol name - filled during grammar validation - shallow pointer */
   int                   *ruleip;                             /* Array of rule IDs - filled by grammar validation */
   size_t                 rulel;                              /* Size of the rule IDs array - filled by grammar validation */
-  short                  haveRejectionb;                     /* When true, valuation go to the ASF mode - filled by grammar validation */
   unsigned int           nbupdatei;                          /* Number of updates - used in grammar ESLIF actions */
   char                  *asciishows;                         /* Grammar show (ASCII) */
   int                    discardi;                           /* Discard symbol ID - filled during grammar validation */
@@ -233,22 +242,18 @@ struct marpaESLIFGrammar {
 };
 
 struct marpaESLIFValue {
-  marpaESLIF_t             *marpaESLIFp;
-  marpaESLIFRecognizer_t   *marpaESLIFRecognizerp;
-  marpaESLIFValueOption_t   marpaESLIFValueOption;
-  marpaWrapperValue_t      *marpaWrapperValuep;
-  marpaWrapperAsfValue_t   *marpaWrapperAsfValuep;
-  short                     previousPassWasPassthroughb;
-  int                       previousArg0i;
-  int                       previousArgni;
-  genericStack_t           *valueStackp;
-  genericStack_t           *typeStackp;
-  genericStack_t           *contextStackp;
-  short                     inValuationb;
-  marpaESLIF_symbol_t      *symbolp;
-  marpaESLIF_rule_t        *rulep;
-  char                     *actions;
-  int                       wantedOutputStacki;
+  marpaESLIF_t            *marpaESLIFp;
+  marpaESLIFRecognizer_t  *marpaESLIFRecognizerp;
+  marpaESLIFValueOption_t  marpaESLIFValueOption;
+  marpaWrapperValue_t     *marpaWrapperValuep;
+  short                    previousPassWasPassthroughb;
+  int                      previousArg0i;
+  int                      previousArgni;
+  genericStack_t          *valueResultStackp;
+  short                    inValuationb;
+  marpaESLIF_symbol_t     *symbolp;
+  marpaESLIF_rule_t       *rulep;
+  char                    *actions;
 };
 
 struct marpaESLIFRecognizer {
@@ -314,7 +319,6 @@ struct marpaESLIFRecognizer {
   short                        noEventb;       /* No event mode */
   short                        discardb;       /* Discard mode */
   short                        exceptionb;     /* Exception mode */
-  genericStack_t              *exceptionStackp; /* This variable is never owned by the recognizer - it is created during valuation */
   short                        silentb;        /* Silent mode */
   short                        haveLexemeb;    /* Remember if this recognizer have at least one lexeme */
   size_t                       linel;          /* Line number */
@@ -332,6 +336,8 @@ struct marpaESLIFRecognizer {
   short                       *afterEventStatebp;   /* Lexeme after current event states for the CURRENT grammar */
   marpaESLIF_lexeme_data_t   **lastPausepp;         /* Lexeme last pause for the CURRENT grammar */
   marpaESLIF_lexeme_data_t   **lastTrypp;           /* Lexeme or :discard last try for the CURRENT grammar */
+  size_t                       minExceptionSizel;   /* Minimum total matched size before a completion event on a symbol to be checked for exception is considered */
+  size_t                       totalMatchedSizel;   /* Total matched - used only when exceptionb is set */
 };
 
 struct marpaESLIF_lexeme_data {
@@ -370,6 +376,7 @@ struct marpaESLIF_readerContext {
 struct marpaESLIF_cloneContext {
   marpaESLIF_t         *marpaESLIFp;
   marpaESLIF_grammar_t *grammarp;
+  int                   forcedEndEventi;
 };
 
 /* ------------------------------------------- */
@@ -385,6 +392,7 @@ marpaESLIFRecognizerOption_t marpaESLIFRecognizerOption_default_template = {
   0,                 /* disableThresholdb */
   0,                 /* exhaustedb */
   0,                 /* newlineb */
+  0,                 /* trackb */
   MARPAESLIF_BUFSIZ, /* bufsizl */
   50,                /* buftriggerperci */
   50                 /* bufaddperci */
